@@ -1,5 +1,9 @@
 var _pro_s_h_a_d_e__typedefs_8hpp =
 [
+    [ "__PROSHADE_GEMMI_INCLUDE__", "_pro_s_h_a_d_e__typedefs_8hpp.html#a70a1283913b7f504ff3d8367edf40083", null ],
+    [ "M_PI", "_pro_s_h_a_d_e__typedefs_8hpp.html#ae71449b1cc6e6250b91f539153a7a0d3", null ],
+    [ "M_SQRT1_2", "_pro_s_h_a_d_e__typedefs_8hpp.html#acdbb2c2f9429f08916f03c8786d2d2d7", null ],
+    [ "PROSHADE_TYPEDEFS", "_pro_s_h_a_d_e__typedefs_8hpp.html#a76b75db6b443d376920a7f3fa713422f", null ],
     [ "proshade_complex", "_pro_s_h_a_d_e__typedefs_8hpp.html#a10134cf48549b890102ac9d6459f8218", null ],
     [ "proshade_double", "_pro_s_h_a_d_e__typedefs_8hpp.html#acfed351cfd7495b3548de559c62a4d9e", null ],
     [ "proshade_signed", "_pro_s_h_a_d_e__typedefs_8hpp.html#a7a2e924855f89dbdb3b14c35de0d5109", null ],
