@@ -1,6 +1,7 @@
 var class_pro_s_h_a_d_e__settings =
 [
     [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#a5dc483c889427fdae60c740a106ce3ff", null ],
+    [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#af0ce3f9c67d8f0dee7db52a84716a519", null ],
     [ "ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#ae88f04ca81dc11f83329552e9f8e0d4c", null ],
     [ "~ProSHADE_settings", "class_pro_s_h_a_d_e__settings.html#a46ba91a2feeaccb274bc01aff5efb9c2", null ],
     [ "addStructure", "class_pro_s_h_a_d_e__settings.html#a0024967775d544e8512b6b157d53c1d1", null ],
@@ -18,6 +19,8 @@ var class_pro_s_h_a_d_e__settings =
     [ "setBicubicInterpolationSearch", "class_pro_s_h_a_d_e__settings.html#a4cc1e3d2625cfaeda834c583b47e39c5", null ],
     [ "setBoundsSpace", "class_pro_s_h_a_d_e__settings.html#a173a6e8c54ff7d6ed0558d3d34523de3", null ],
     [ "setBoundsThreshold", "class_pro_s_h_a_d_e__settings.html#add15920c73e6255d517e2d97794bcdd5", null ],
+    [ "setBoxCentering", "class_pro_s_h_a_d_e__settings.html#a49b6c5fcb97b0d8dfac4f23c72d74ed4", null ],
+    [ "setCoordExtraSpace", "class_pro_s_h_a_d_e__settings.html#afed8b0454b117a4df1d68eb92638dda2", null ],
     [ "setCorrelationMasking", "class_pro_s_h_a_d_e__settings.html#a412cbcb39b4ce0e18e080aa35cb1cbce", null ],
     [ "setDetectedSymmetry", "class_pro_s_h_a_d_e__settings.html#aaacee048ce8a3489edc77afcb54f0ca0", null ],
     [ "setEnergyLevelsComputation", "class_pro_s_h_a_d_e__settings.html#ad2d51c260ed88aaaa50dd7ca75bfc648", null ],
@@ -60,6 +63,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "setRotationFunctionComputation", "class_pro_s_h_a_d_e__settings.html#adc025bad387952e9a2b9395775ad7903", null ],
     [ "setSameBoundaries", "class_pro_s_h_a_d_e__settings.html#aa84f6622f8b7ac034f171cbe29d3bcab", null ],
     [ "setSphereDistances", "class_pro_s_h_a_d_e__settings.html#a5e84faf0910dadc44f0add82443e839e", null ],
+    [ "setSymmetryCentreSearch", "class_pro_s_h_a_d_e__settings.html#ad9968b2136d3483e2dba45c156dc11f8", null ],
     [ "setTaylorSeriesCap", "class_pro_s_h_a_d_e__settings.html#acf005edf3e38fe6050d25f8910d3f079", null ],
     [ "setTraceSigmaComputation", "class_pro_s_h_a_d_e__settings.html#a2e5acd2c944f50fe4736be5c738e61fd", null ],
     [ "setTypicalNoiseSize", "class_pro_s_h_a_d_e__settings.html#ac5b55f7ece119e9d9e980d89d59a6df8", null ],
@@ -77,14 +81,19 @@ var class_pro_s_h_a_d_e__settings =
     [ "blurFactor", "class_pro_s_h_a_d_e__settings.html#a51c87d0b415c8eaa517dbb9b5496e7e9", null ],
     [ "boundsExtraSpace", "class_pro_s_h_a_d_e__settings.html#a633435d4c8a7fd6533016c00ad9ba791", null ],
     [ "boundsSimilarityThreshold", "class_pro_s_h_a_d_e__settings.html#a827e3241fa6401027e0526fffb8b281d", null ],
+    [ "boxCentre", "class_pro_s_h_a_d_e__settings.html#aa6c69d8fbdf79ef0f5f4b867dcbbe86f", null ],
+    [ "centrePosition", "class_pro_s_h_a_d_e__settings.html#a6f93b0061117d6bb3fc8cea3c4314957", null ],
     [ "changeMapResolution", "class_pro_s_h_a_d_e__settings.html#ab61d2183930ea26b3d49e7662052e83b", null ],
     [ "changeMapResolutionTriLinear", "class_pro_s_h_a_d_e__settings.html#a4f49a4f2263aa12ccb1737f8dc32c9ac", null ],
     [ "computeEnergyLevelsDesc", "class_pro_s_h_a_d_e__settings.html#a23a96d41d415195813dd3237ae47b614", null ],
     [ "computeRotationFuncDesc", "class_pro_s_h_a_d_e__settings.html#a4ee1d1392407d1317274a793186129aa", null ],
     [ "computeTraceSigmaDesc", "class_pro_s_h_a_d_e__settings.html#a48bff4bebb6268c286b68bfd6663d954", null ],
+    [ "coOrdsExtraSpace", "class_pro_s_h_a_d_e__settings.html#a31fb6004cbb5a70ad3c3e6aeb1816780", null ],
     [ "correlationKernel", "class_pro_s_h_a_d_e__settings.html#ad7070cc8a98a8b8a040232eae8b2fbf3", null ],
     [ "detectedSymmetry", "class_pro_s_h_a_d_e__settings.html#a42b012ec753ebd1d87a0b6f557e97d1a", null ],
     [ "enLevMatrixPowerWeight", "class_pro_s_h_a_d_e__settings.html#a85edabe260e0466726b5875969dd18e3", null ],
+    [ "fastISearch", "class_pro_s_h_a_d_e__settings.html#a3d484590819881311b611ab08c2ce9b0", null ],
+    [ "findSymCentre", "class_pro_s_h_a_d_e__settings.html#a9412b832af7b85c8226ba033e2b0b756", null ],
     [ "firstModelOnly", "class_pro_s_h_a_d_e__settings.html#a0ee28b12499554d8dff8752cd5ef072a", null ],
     [ "forceBounds", "class_pro_s_h_a_d_e__settings.html#aa3e24ef5a66fa7204a2ba9c27f2f12b9", null ],
     [ "forceP1", "class_pro_s_h_a_d_e__settings.html#acffa14a2c2121b5b425fcabdb7b3ba6a", null ],
@@ -100,6 +109,7 @@ var class_pro_s_h_a_d_e__settings =
     [ "maxBandwidth", "class_pro_s_h_a_d_e__settings.html#a8324ed7ec9c19df21511f117df80ab11", null ],
     [ "maxSphereDists", "class_pro_s_h_a_d_e__settings.html#a42e4b11981a2d3a518cb3c70e5470fb2", null ],
     [ "maxSymmetryFold", "class_pro_s_h_a_d_e__settings.html#afcece610f52c27cadefb217f1d0c278c", null ],
+    [ "messageShift", "class_pro_s_h_a_d_e__settings.html#a286453ecf4904c2957e792a24567af6b", null ],
     [ "minSymPeak", "class_pro_s_h_a_d_e__settings.html#ac914dc8b6ee2e35286beabb1b6611b74", null ],
     [ "moveToCOM", "class_pro_s_h_a_d_e__settings.html#a37c9037721c1ad28ad6421a31dbcd8d8", null ],
     [ "noIQRsFromMedianNaivePeak", "class_pro_s_h_a_d_e__settings.html#a3e7948fd9177bd39ed3dd2320ea2b0bc", null ],
