@@ -21,7 +21,6 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__distances_8cpp.html":[3,0,0,1,4],
 "_pro_s_h_a_d_e__distances_8cpp_source.html":[3,0,0,1,4],
 "_pro_s_h_a_d_e__distances_8hpp.html":[3,0,0,1,5],
-"_pro_s_h_a_d_e__distances_8hpp.html#a0f062b77c4b5360a17249e74e6a15538":[3,0,0,1,5,6],
 "_pro_s_h_a_d_e__distances_8hpp.html#a1a977a344baa3b1697743060789bceb5":[3,0,0,1,5,4],
 "_pro_s_h_a_d_e__distances_8hpp.html#a22db876a8cca08073f4db031996f537b":[3,0,0,1,5,8],
 "_pro_s_h_a_d_e__distances_8hpp.html#a2642dc2bcb0c1560e7f287956a49b189":[3,0,0,1,5,14],
@@ -32,6 +31,7 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__distances_8hpp.html#a6e15740000a0079151a2d24dbbdebb2e":[3,0,0,1,5,12],
 "_pro_s_h_a_d_e__distances_8hpp.html#a73523c64e878054affd0dba8390c8de4":[3,0,0,1,5,10],
 "_pro_s_h_a_d_e__distances_8hpp.html#a8ed62a245d4fa9750f98b60d755b61c1":[3,0,0,1,5,3],
+"_pro_s_h_a_d_e__distances_8hpp.html#ab5b11e10f0f11541ebb8deeaa427700d":[3,0,0,1,5,6],
 "_pro_s_h_a_d_e__distances_8hpp.html#ac96ff1a23997199af76e58885a1ee1e2":[3,0,0,1,5,13],
 "_pro_s_h_a_d_e__distances_8hpp.html#acde4bb62c09903a347ecde6f0a5302b1":[3,0,0,1,5,7],
 "_pro_s_h_a_d_e__distances_8hpp.html#ad7d8c822491454700995e0f1bc702e48":[3,0,0,1,5,15],
@@ -46,9 +46,10 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__io_8cpp.html":[3,0,0,1,8],
 "_pro_s_h_a_d_e__io_8cpp_source.html":[3,0,0,1,8],
 "_pro_s_h_a_d_e__io_8hpp.html":[3,0,0,1,9],
-"_pro_s_h_a_d_e__io_8hpp.html#a2047cb9106e44b8de3174e34b9578f80":[3,0,0,1,9,3],
+"_pro_s_h_a_d_e__io_8hpp.html#a189c98238a6caef5d7dfde5cde999709":[3,0,0,1,9,3],
+"_pro_s_h_a_d_e__io_8hpp.html#a1e3fc8ac7658bf54776a0fbb4e8286cd":[3,0,0,1,9,1],
 "_pro_s_h_a_d_e__io_8hpp.html#a2e438f3d348e3e065f798031d5a33d09":[3,0,0,1,9,11],
-"_pro_s_h_a_d_e__io_8hpp.html#a354a3899d17c6c5d4bad042dc00f4554":[3,0,0,1,9,2],
+"_pro_s_h_a_d_e__io_8hpp.html#a3fa28eb91fd8504c7397f76f4202ddb8":[3,0,0,1,9,2],
 "_pro_s_h_a_d_e__io_8hpp.html#a63ae2cc7f413d224e5d651ed579e9afb":[3,0,0,1,9,5],
 "_pro_s_h_a_d_e__io_8hpp.html#a6457a6070e82b0955205ed0a95ea3040":[3,0,0,1,9,9],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964":[3,0,0,1,9,0],
@@ -56,41 +57,41 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a2ebd61b90723c41f6f03a4a1f5791f1e":[3,0,0,1,9,0,2],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a5f47bf43e5397417deb998646477b2db":[3,0,0,1,9,0,3],
 "_pro_s_h_a_d_e__io_8hpp.html#a80a7305e00c670509c352f2e6c6a7964a931e41099ae6c64ea034b6485a46dfaa":[3,0,0,1,9,0,0],
+"_pro_s_h_a_d_e__io_8hpp.html#a89bc3f1b071b14daf8795335b139c85b":[3,0,0,1,9,4],
 "_pro_s_h_a_d_e__io_8hpp.html#a9677e06f0781855b9046aab1b3638831":[3,0,0,1,9,10],
 "_pro_s_h_a_d_e__io_8hpp.html#a9f714e15a7bc56dbe846fda6bb1d9c9e":[3,0,0,1,9,12],
-"_pro_s_h_a_d_e__io_8hpp.html#aa5e21f1b3dc18338da35951b248e6e38":[3,0,0,1,9,1],
 "_pro_s_h_a_d_e__io_8hpp.html#abc5e6a82b6b44e3666abfc190dc0bc64":[3,0,0,1,9,7],
 "_pro_s_h_a_d_e__io_8hpp.html#ad93f9644c5b132193b4ddd282f50abce":[3,0,0,1,9,8],
-"_pro_s_h_a_d_e__io_8hpp.html#adae94658a4eec4c994e10d267b00fe4c":[3,0,0,1,9,4],
 "_pro_s_h_a_d_e__io_8hpp.html#ae496132c658b22a5abb5d7aaca5e1f56":[3,0,0,1,9,6],
 "_pro_s_h_a_d_e__io_8hpp_source.html":[3,0,0,1,9],
 "_pro_s_h_a_d_e__map_manip_8cpp.html":[3,0,0,1,10],
 "_pro_s_h_a_d_e__map_manip_8cpp_source.html":[3,0,0,1,10],
 "_pro_s_h_a_d_e__map_manip_8hpp.html":[3,0,0,1,11],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a037825616c60bef58075284449872642":[3,0,0,1,11,20],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a037825616c60bef58075284449872642":[3,0,0,1,11,21],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a05098c48b9e98a02fc1bda2f4fbc5415":[3,0,0,1,11,16],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a167f7a9dbd061752d2a099181090a3b8":[3,0,0,1,11,25],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a1f9e6ab7a6db084069402d83ad152c01":[3,0,0,1,11,21],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a167f7a9dbd061752d2a099181090a3b8":[3,0,0,1,11,26],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a1f9e6ab7a6db084069402d83ad152c01":[3,0,0,1,11,22],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a272ed511f8e39433857ba6c733fa009a":[3,0,0,1,11,10],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a2f09d5bdfb5450f2da8395f8770ef137":[3,0,0,1,11,30],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a2f09d5bdfb5450f2da8395f8770ef137":[3,0,0,1,11,31],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a3bd5d0937bf5a545008b06593c5722a7":[3,0,0,1,11,13],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a3d107e20dfeb5b5442fc3d0ba70bf2ef":[3,0,0,1,11,12],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a42699d52d1be0d24e58deea4e25439bf":[3,0,0,1,11,17],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a47d4376c3535050c07ba3e76faa1ba48":[3,0,0,1,11,23],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a4c1ee71ada97967f49ae1b338d6f43f9":[3,0,0,1,11,29],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a50df80b02427f9f55a2c7af033a9fb93":[3,0,0,1,11,22],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a47d4376c3535050c07ba3e76faa1ba48":[3,0,0,1,11,24],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a4c1ee71ada97967f49ae1b338d6f43f9":[3,0,0,1,11,30],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a50df80b02427f9f55a2c7af033a9fb93":[3,0,0,1,11,23],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a5d1e80b32498ac8019bd2701b49cad2d":[3,0,0,1,11,14],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a5db74cc13dd4b64cf0a8377ed078b47c":[3,0,0,1,11,28],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a5db74cc13dd4b64cf0a8377ed078b47c":[3,0,0,1,11,29],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a5ea0089ffb4d36356c527a1d1c9d7960":[3,0,0,1,11,20],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a7c88b1152378beca4ccee251f2fb5e06":[3,0,0,1,11,0],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a7d5680a284686d86c28b5300db111ca5":[3,0,0,1,11,24],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#a8993520350e1eab8f3eb041c8115cac5":[3,0,0,1,11,26],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a7d5680a284686d86c28b5300db111ca5":[3,0,0,1,11,25],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#a8993520350e1eab8f3eb041c8115cac5":[3,0,0,1,11,27],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#a94dfbe2867f4e294dbb49284881fcb2a":[3,0,0,1,11,19],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#aa373379d6fa4ebebb0f62e66384186e1":[3,0,0,1,11,8],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#aa74663cb1126a4a3235f27945e4ac66f":[3,0,0,1,11,15],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#aaad67127777eab70acca5952a7838d26":[3,0,0,1,11,11],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#abc6c505ea6b876bfae4d5f45dab63e98":[3,0,0,1,11,3],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#ac2650a79c20be34894c23d73ffaae750":[3,0,0,1,11,18],
-"_pro_s_h_a_d_e__map_manip_8hpp.html#ac311071faa65db4dfc1886d2a6de78ef":[3,0,0,1,11,27],
+"_pro_s_h_a_d_e__map_manip_8hpp.html#ac311071faa65db4dfc1886d2a6de78ef":[3,0,0,1,11,28],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#acf1e3e4bba204a62b6c3046e5c4c0e77":[3,0,0,1,11,7],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#ad4feb37444a93df167935cf42d1209f6":[3,0,0,1,11,9],
 "_pro_s_h_a_d_e__map_manip_8hpp.html#adc0d808ba88ad0e023ba8391aa44be95":[3,0,0,1,11,5],
@@ -102,73 +103,88 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__maths_8cpp.html":[3,0,0,1,12],
 "_pro_s_h_a_d_e__maths_8cpp_source.html":[3,0,0,1,12],
 "_pro_s_h_a_d_e__maths_8hpp.html":[3,0,0,1,13],
-"_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45":[3,0,0,1,13,46],
-"_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936":[3,0,0,1,13,38],
-"_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7":[3,0,0,1,13,61],
-"_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151":[3,0,0,1,13,45],
-"_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1":[3,0,0,1,13,44],
-"_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2":[3,0,0,1,13,33],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd":[3,0,0,1,13,42],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495":[3,0,0,1,13,22],
-"_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970":[3,0,0,1,13,8],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea":[3,0,0,1,13,17],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b":[3,0,0,1,13,23],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde":[3,0,0,1,13,59],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7":[3,0,0,1,13,9],
-"_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444":[3,0,0,1,13,14],
-"_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad":[3,0,0,1,13,5],
-"_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49":[3,0,0,1,13,37],
-"_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601":[3,0,0,1,13,18],
-"_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d":[3,0,0,1,13,26],
-"_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147":[3,0,0,1,13,51],
-"_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e":[3,0,0,1,13,54],
-"_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7":[3,0,0,1,13,25],
-"_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91":[3,0,0,1,13,43],
-"_pro_s_h_a_d_e__maths_8hpp.html#a4a379ad8635541b0c7f7f6349822b2a4":[3,0,0,1,13,29],
+"_pro_s_h_a_d_e__maths_8hpp.html#a01087ea3e0db56758d1771618e2e4a45":[3,0,0,1,13,60],
+"_pro_s_h_a_d_e__maths_8hpp.html#a044f4684d6d52d1242225e3969a4813b":[3,0,0,1,13,18],
+"_pro_s_h_a_d_e__maths_8hpp.html#a0860239f5ba95153f2b12d40a5742936":[3,0,0,1,13,52],
+"_pro_s_h_a_d_e__maths_8hpp.html#a0cbbac6da7eaf965ee286850344c51e7":[3,0,0,1,13,76],
+"_pro_s_h_a_d_e__maths_8hpp.html#a10bbc3e6e75c26cfbe90664dd2a7d151":[3,0,0,1,13,59],
+"_pro_s_h_a_d_e__maths_8hpp.html#a12a5f7b87baedbe1cd37ad588d3fca92":[3,0,0,1,13,6],
+"_pro_s_h_a_d_e__maths_8hpp.html#a18222a942e5fff8eecd15f1235c609e1":[3,0,0,1,13,58],
+"_pro_s_h_a_d_e__maths_8hpp.html#a1823adaca871244e42347ecb8ed834a2":[3,0,0,1,13,47],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2380a3710f7dbe672519c3adda30f7cd":[3,0,0,1,13,56],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2454c19169bb38d616e52b99f1dc4495":[3,0,0,1,13,32],
+"_pro_s_h_a_d_e__maths_8hpp.html#a254fece06e1cfce122a11ddea4f71970":[3,0,0,1,13,10],
+"_pro_s_h_a_d_e__maths_8hpp.html#a26fa82e82a6a4af696cfae0581785446":[3,0,0,1,13,36],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2ac3b534f974de25b092e9d48d9f7dea":[3,0,0,1,13,21],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2b17617f8b3c42c5199948828cd1a57b":[3,0,0,1,13,35],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2b2f67cba1eea57f19fdaf062db74fde":[3,0,0,1,13,74],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2bbee3728be168eb54099ddb9bc0689a":[3,0,0,1,13,20],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2ca5a3aedba75f52aaf707edc4e790f7":[3,0,0,1,13,11],
+"_pro_s_h_a_d_e__maths_8hpp.html#a2f9c7716f6ab682e8548ab77efcdc444":[3,0,0,1,13,16],
+"_pro_s_h_a_d_e__maths_8hpp.html#a31c91064de64aef9f8278d533f8188ad":[3,0,0,1,13,8],
+"_pro_s_h_a_d_e__maths_8hpp.html#a39cf8a79d316806c1140c6cd7a9b49ca":[3,0,0,1,13,27],
+"_pro_s_h_a_d_e__maths_8hpp.html#a39eafef902a49cc0816a2ed675c14a49":[3,0,0,1,13,51],
+"_pro_s_h_a_d_e__maths_8hpp.html#a3b37ae1c35d048fd5dbff0a2cfcc4601":[3,0,0,1,13,22],
+"_pro_s_h_a_d_e__maths_8hpp.html#a3d4604176a61820f5fcb95e372861c1d":[3,0,0,1,13,40],
+"_pro_s_h_a_d_e__maths_8hpp.html#a3f12eb80331377a36ee6b3a4f8e65147":[3,0,0,1,13,65],
+"_pro_s_h_a_d_e__maths_8hpp.html#a4348a7a36275c9cea20b5c27093c9b7e":[3,0,0,1,13,69],
+"_pro_s_h_a_d_e__maths_8hpp.html#a45fbcfaeaabf9bae2fbd7d46a5fb4bc7":[3,0,0,1,13,39],
+"_pro_s_h_a_d_e__maths_8hpp.html#a4915884de2c0c846d74baf77003ca29c":[3,0,0,1,13,24],
+"_pro_s_h_a_d_e__maths_8hpp.html#a49f093fbdd34498d27a4d8998b620c91":[3,0,0,1,13,57],
+"_pro_s_h_a_d_e__maths_8hpp.html#a4c9eee80c21be71c62220ea338c0a54b":[3,0,0,1,13,37],
+"_pro_s_h_a_d_e__maths_8hpp.html#a4d8ecf33b4e65b2404ce064b054845b1":[3,0,0,1,13,26],
 "_pro_s_h_a_d_e__maths_8hpp.html#a4f2619c7f3b8d628af9cb356778e9807":[3,0,0,1,13,2],
-"_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2":[3,0,0,1,13,47],
-"_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a":[3,0,0,1,13,36],
-"_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d":[3,0,0,1,13,13],
-"_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c":[3,0,0,1,13,16],
-"_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192":[3,0,0,1,13,27],
-"_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e":[3,0,0,1,13,53],
-"_pro_s_h_a_d_e__maths_8hpp.html#a6c83ae1b2f9783ad8df6ff6dfbbc3b9d":[3,0,0,1,13,15],
-"_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065":[3,0,0,1,13,35],
-"_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b":[3,0,0,1,13,50],
-"_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0":[3,0,0,1,13,60],
-"_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675":[3,0,0,1,13,21],
-"_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567":[3,0,0,1,13,12],
-"_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff":[3,0,0,1,13,48],
-"_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8":[3,0,0,1,13,57],
-"_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df":[3,0,0,1,13,30],
+"_pro_s_h_a_d_e__maths_8hpp.html#a51486f6276c28c1b503f19c36007b9e2":[3,0,0,1,13,61],
+"_pro_s_h_a_d_e__maths_8hpp.html#a51be603bcedf202a40a490aa3fc8d45a":[3,0,0,1,13,50],
+"_pro_s_h_a_d_e__maths_8hpp.html#a5a65abe8c99adbd99419b9c65d25a3b2":[3,0,0,1,13,5],
+"_pro_s_h_a_d_e__maths_8hpp.html#a5f2b9b9da97b52b7e5cccc08493d0e0d":[3,0,0,1,13,15],
+"_pro_s_h_a_d_e__maths_8hpp.html#a61807efeb86ea021f3d17ac531911c3c":[3,0,0,1,13,19],
+"_pro_s_h_a_d_e__maths_8hpp.html#a62133f51851217e3cb28dff2f520d192":[3,0,0,1,13,41],
+"_pro_s_h_a_d_e__maths_8hpp.html#a6359dd366cdd986f5ad155bff8235a8e":[3,0,0,1,13,67],
+"_pro_s_h_a_d_e__maths_8hpp.html#a64ba4ba55d58078eeea8b70311e4ab49":[3,0,0,1,13,7],
+"_pro_s_h_a_d_e__maths_8hpp.html#a689d9fe55f079cb37a7446103f6103ba":[3,0,0,1,13,68],
+"_pro_s_h_a_d_e__maths_8hpp.html#a6c83ae1b2f9783ad8df6ff6dfbbc3b9d":[3,0,0,1,13,17],
+"_pro_s_h_a_d_e__maths_8hpp.html#a6e2f7de1bba288270ce2cc772d28d065":[3,0,0,1,13,49],
+"_pro_s_h_a_d_e__maths_8hpp.html#a73c2321ffcef5079634493d9bf65749b":[3,0,0,1,13,64],
+"_pro_s_h_a_d_e__maths_8hpp.html#a79e789452e327bb07a53c5358f4d3eb0":[3,0,0,1,13,75],
+"_pro_s_h_a_d_e__maths_8hpp.html#a7caf87603d759cb0de1b0bd834ae8f6d":[3,0,0,1,13,33],
+"_pro_s_h_a_d_e__maths_8hpp.html#a7e69b64278319ae1a1268d1a55545675":[3,0,0,1,13,31],
+"_pro_s_h_a_d_e__maths_8hpp.html#a7fa32a45083a0154c5f0b039bae9ab39":[3,0,0,1,13,28],
+"_pro_s_h_a_d_e__maths_8hpp.html#a83ac617b105e1ca1729800c5f290b567":[3,0,0,1,13,14],
+"_pro_s_h_a_d_e__maths_8hpp.html#a894d87e94446db04492b663e54a74bff":[3,0,0,1,13,62],
+"_pro_s_h_a_d_e__maths_8hpp.html#a8a7c6330e101fb6d729aaf6f545db9c8":[3,0,0,1,13,72],
+"_pro_s_h_a_d_e__maths_8hpp.html#a91d9c1e755e7bf89e6de8f79fd4936df":[3,0,0,1,13,44],
 "_pro_s_h_a_d_e__maths_8hpp.html#aa2702798938d50ec2a55e46cbc31333e":[3,0,0,1,13,4],
-"_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea":[3,0,0,1,13,55],
+"_pro_s_h_a_d_e__maths_8hpp.html#aa2da3e6dc4d41b8f09b47982fe74b3ea":[3,0,0,1,13,70],
+"_pro_s_h_a_d_e__maths_8hpp.html#aa54f5391ab62bf98a331d79d6114c346":[3,0,0,1,13,30],
 "_pro_s_h_a_d_e__maths_8hpp.html#aa5a356017340781739a3bd66c716cfa5":[3,0,0,1,13,3],
-"_pro_s_h_a_d_e__maths_8hpp.html#aafc6f1626c7463de53c9f4f6fa11db22":[3,0,0,1,13,28],
-"_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993":[3,0,0,1,13,6],
-"_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e":[3,0,0,1,13,10],
-"_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1":[3,0,0,1,13,39],
-"_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e":[3,0,0,1,13,49],
-"_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a":[3,0,0,1,13,52],
-"_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296":[3,0,0,1,13,56],
-"_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6":[3,0,0,1,13,11],
-"_pro_s_h_a_d_e__maths_8hpp.html#acdc79bf2506934c9ebbda9c13a2722ad":[3,0,0,1,13,7],
-"_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706":[3,0,0,1,13,32],
-"_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc":[3,0,0,1,13,20],
-"_pro_s_h_a_d_e__maths_8hpp.html#ad3c391ac63c921d19d8d4956d58e0ea8":[3,0,0,1,13,19],
-"_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272":[3,0,0,1,13,40],
-"_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce":[3,0,0,1,13,41],
-"_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28":[3,0,0,1,13,31],
-"_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603":[3,0,0,1,13,24],
-"_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a":[3,0,0,1,13,58],
-"_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432":[3,0,0,1,13,34],
+"_pro_s_h_a_d_e__maths_8hpp.html#aad5409074bece14a244fad191524a687":[3,0,0,1,13,42],
+"_pro_s_h_a_d_e__maths_8hpp.html#ab02121573c2176b879404bad104b33e4":[3,0,0,1,13,34],
+"_pro_s_h_a_d_e__maths_8hpp.html#ab32d795fc4057093f27e5981551f5d99":[3,0,0,1,13,23],
+"_pro_s_h_a_d_e__maths_8hpp.html#ab98abe6f7fac976a70b608951dbdf993":[3,0,0,1,13,9],
+"_pro_s_h_a_d_e__maths_8hpp.html#abc59a55f5ed21de90e351005c58a871e":[3,0,0,1,13,12],
+"_pro_s_h_a_d_e__maths_8hpp.html#abd9fe573a48f499dd7d1df4f779222f1":[3,0,0,1,13,53],
+"_pro_s_h_a_d_e__maths_8hpp.html#ac027bbd2cde68eb9d677e8b11b90cc2e":[3,0,0,1,13,63],
+"_pro_s_h_a_d_e__maths_8hpp.html#ac3b355465dd2244b51e579dcb8669b3a":[3,0,0,1,13,66],
+"_pro_s_h_a_d_e__maths_8hpp.html#ac6c48ee69a642f279354789f09b02296":[3,0,0,1,13,71],
+"_pro_s_h_a_d_e__maths_8hpp.html#ac9b05344ffead449c29a333a57b404f6":[3,0,0,1,13,13],
+"_pro_s_h_a_d_e__maths_8hpp.html#acf6c5376edac98e54ef0e418cd05d706":[3,0,0,1,13,46],
+"_pro_s_h_a_d_e__maths_8hpp.html#ad30fc4ec4f4239e4860270955a28fdcc":[3,0,0,1,13,25],
+"_pro_s_h_a_d_e__maths_8hpp.html#adccd7507561d95a44315b0eebe285272":[3,0,0,1,13,54],
+"_pro_s_h_a_d_e__maths_8hpp.html#adea245a9b2b305f970be1ed62b141cce":[3,0,0,1,13,55],
+"_pro_s_h_a_d_e__maths_8hpp.html#ae6f6afcef5b90ca77d7d6a9e91824e28":[3,0,0,1,13,45],
+"_pro_s_h_a_d_e__maths_8hpp.html#ae9f376bb341b192fff008b9b4ef5c603":[3,0,0,1,13,38],
+"_pro_s_h_a_d_e__maths_8hpp.html#aec42a4efcef6dffaf047acde57acea99":[3,0,0,1,13,43],
+"_pro_s_h_a_d_e__maths_8hpp.html#af185ca14eb5d82fb126092767746e00a":[3,0,0,1,13,73],
+"_pro_s_h_a_d_e__maths_8hpp.html#aff2cf3abcfbf8f70b24b369ee3392b12":[3,0,0,1,13,29],
+"_pro_s_h_a_d_e__maths_8hpp.html#affab74b910cda2ee3faa461740a7a432":[3,0,0,1,13,48],
 "_pro_s_h_a_d_e__maths_8hpp_source.html":[3,0,0,1,13],
 "_pro_s_h_a_d_e__messages_8cpp.html":[3,0,0,1,14],
 "_pro_s_h_a_d_e__messages_8cpp_source.html":[3,0,0,1,14],
 "_pro_s_h_a_d_e__messages_8hpp.html":[3,0,0,1,15],
 "_pro_s_h_a_d_e__messages_8hpp.html#a368423cb210e9de613d652b3770fb533":[3,0,0,1,15,4],
 "_pro_s_h_a_d_e__messages_8hpp.html#a4653e05cb29b2ded588ae4ddcbdd8aee":[3,0,0,1,15,2],
-"_pro_s_h_a_d_e__messages_8hpp.html#a6aa8cdb600cad623409802cfaed494fa":[3,0,0,1,15,1],
+"_pro_s_h_a_d_e__messages_8hpp.html#a4f98d32ed17424a1d8bf451a68370e20":[3,0,0,1,15,1],
 "_pro_s_h_a_d_e__messages_8hpp.html#a91b5970b1bfadd74d2fe9f0b20b0baeb":[3,0,0,1,15,0],
 "_pro_s_h_a_d_e__messages_8hpp.html#addbb90f2b4199441f60e241ac850daa2":[3,0,0,1,15,3],
 "_pro_s_h_a_d_e__messages_8hpp_source.html":[3,0,0,1,15],
@@ -176,78 +192,62 @@ var NAVTREEINDEX0 =
 "_pro_s_h_a_d_e__misc_8cpp_source.html":[3,0,0,1,16],
 "_pro_s_h_a_d_e__misc_8hpp.html":[3,0,0,1,17],
 "_pro_s_h_a_d_e__misc_8hpp.html#a16336bdf0b391c953a549d3df115d691":[3,0,0,1,17,7],
-"_pro_s_h_a_d_e__misc_8hpp.html#a1d2cb8d66b6afa816c3f49f1a864e37b":[3,0,0,1,17,15],
+"_pro_s_h_a_d_e__misc_8hpp.html#a1d2cb8d66b6afa816c3f49f1a864e37b":[3,0,0,1,17,16],
 "_pro_s_h_a_d_e__misc_8hpp.html#a2d19df22d740c51de6edafbf679ae3fd":[3,0,0,1,17,5],
-"_pro_s_h_a_d_e__misc_8hpp.html#a2e915d310892aea124046acd14db4a84":[3,0,0,1,17,16],
+"_pro_s_h_a_d_e__misc_8hpp.html#a2e915d310892aea124046acd14db4a84":[3,0,0,1,17,17],
 "_pro_s_h_a_d_e__misc_8hpp.html#a58f65a0980ed91146891e6c33ab7383a":[3,0,0,1,17,4],
 "_pro_s_h_a_d_e__misc_8hpp.html#a60e14917f99e745c35cc400475ad6ca5":[3,0,0,1,17,6],
 "_pro_s_h_a_d_e__misc_8hpp.html#a68c3eafaeea1c1873c33525f337f9d0b":[3,0,0,1,17,1],
-"_pro_s_h_a_d_e__misc_8hpp.html#a7289af99d74bd31fec24a61b0436160a":[3,0,0,1,17,14],
+"_pro_s_h_a_d_e__misc_8hpp.html#a7289af99d74bd31fec24a61b0436160a":[3,0,0,1,17,15],
 "_pro_s_h_a_d_e__misc_8hpp.html#a86e2bb172f766ab4a620df482d2fe481":[3,0,0,1,17,8],
 "_pro_s_h_a_d_e__misc_8hpp.html#a8726bba32075a23287d2295354a8d464":[3,0,0,1,17,12],
 "_pro_s_h_a_d_e__misc_8hpp.html#a8a52d854a63ecad80c1805d601ffcf96":[3,0,0,1,17,3],
 "_pro_s_h_a_d_e__misc_8hpp.html#aa3103c7b5e2dc2cbf1778705c7693334":[3,0,0,1,17,0],
 "_pro_s_h_a_d_e__misc_8hpp.html#ab0d38ce581c60d246fcf62ed05235e7f":[3,0,0,1,17,13],
-"_pro_s_h_a_d_e__misc_8hpp.html#ad14d6427df4269728627fcd880abaf31":[3,0,0,1,17,17],
+"_pro_s_h_a_d_e__misc_8hpp.html#ad14d6427df4269728627fcd880abaf31":[3,0,0,1,17,18],
 "_pro_s_h_a_d_e__misc_8hpp.html#ad9fbf28fda3873fc511fa2000ccba86c":[3,0,0,1,17,2],
 "_pro_s_h_a_d_e__misc_8hpp.html#ae36ae89607a7676c427956b88751f639":[3,0,0,1,17,9],
 "_pro_s_h_a_d_e__misc_8hpp.html#af556836aa9286c1571196de442a6b493":[3,0,0,1,17,10],
+"_pro_s_h_a_d_e__misc_8hpp.html#afc48122cd1adf605eb8f7479cd197585":[3,0,0,1,17,14],
 "_pro_s_h_a_d_e__misc_8hpp.html#aff0d8344fdd83482e5531eadedaac550":[3,0,0,1,17,11],
 "_pro_s_h_a_d_e__misc_8hpp_source.html":[3,0,0,1,17],
 "_pro_s_h_a_d_e__overlay_8cpp.html":[3,0,0,1,18],
 "_pro_s_h_a_d_e__overlay_8cpp_source.html":[3,0,0,1,18],
 "_pro_s_h_a_d_e__overlay_8hpp.html":[3,0,0,1,19],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a1e7fa43107bc9a9fce49d5954a93c962":[3,0,0,1,19,10],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a2a0722746f5c10a2ce4805513cb99fe9":[3,0,0,1,19,1],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a448b6438ea9979e18af75f419f175603":[3,0,0,1,19,6],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a1e7fa43107bc9a9fce49d5954a93c962":[3,0,0,1,19,8],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a448b6438ea9979e18af75f419f175603":[3,0,0,1,19,4],
 "_pro_s_h_a_d_e__overlay_8hpp.html#a5f5eacf55d707e1d80d3df360fc0fe91":[3,0,0,1,19,0],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a6f02ec45f8f865fe5a7142509f48e41a":[3,0,0,1,19,3],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a75e695f0a6b627e6a670c5e379230f4c":[3,0,0,1,19,5],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a78c51dc39b75ffb4731c7219b25e290b":[3,0,0,1,19,2],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a92cc970ba9d1e6ab220a0c947ebd5567":[3,0,0,1,19,7],
-"_pro_s_h_a_d_e__overlay_8hpp.html#a96c978e561ed489efc681f640332256a":[3,0,0,1,19,8],
-"_pro_s_h_a_d_e__overlay_8hpp.html#ac173210899aeeae2e207f9acdd7670a7":[3,0,0,1,19,9],
-"_pro_s_h_a_d_e__overlay_8hpp.html#aed7eab7c65fccfa0690ef475ae4e2e9e":[3,0,0,1,19,4],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a6f02ec45f8f865fe5a7142509f48e41a":[3,0,0,1,19,2],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a78c51dc39b75ffb4731c7219b25e290b":[3,0,0,1,19,1],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a92cc970ba9d1e6ab220a0c947ebd5567":[3,0,0,1,19,5],
+"_pro_s_h_a_d_e__overlay_8hpp.html#a96c978e561ed489efc681f640332256a":[3,0,0,1,19,6],
+"_pro_s_h_a_d_e__overlay_8hpp.html#ac173210899aeeae2e207f9acdd7670a7":[3,0,0,1,19,7],
+"_pro_s_h_a_d_e__overlay_8hpp.html#aed7eab7c65fccfa0690ef475ae4e2e9e":[3,0,0,1,19,3],
 "_pro_s_h_a_d_e__overlay_8hpp_source.html":[3,0,0,1,19],
 "_pro_s_h_a_d_e__peak_search_8cpp.html":[3,0,0,1,20],
 "_pro_s_h_a_d_e__peak_search_8cpp_source.html":[3,0,0,1,20],
 "_pro_s_h_a_d_e__peak_search_8hpp.html":[3,0,0,1,21],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#a26e06bc5d7848e1f9da5aeac60ceb989":[3,0,0,1,21,1],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a2f0f9ca11f49a15c4d40f757da9c2eb3":[3,0,0,1,21,17],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a31ee66ea091e22a8abbc77a1afad70cc":[3,0,0,1,21,12],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a2f0f9ca11f49a15c4d40f757da9c2eb3":[3,0,0,1,21,16],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a31ee66ea091e22a8abbc77a1afad70cc":[3,0,0,1,21,11],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#a34517023194b4c96e1e4e378dbc70e34":[3,0,0,1,21,3],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a3728cebdcc0cad1dff8c83dabaeed31c":[3,0,0,1,21,6],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#a4cdab52c30f5b34effa4dbf4352bf85e":[3,0,0,1,21,5],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#a5b70a7d73951db96021a5451b6b3f368":[3,0,0,1,21,4],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a7081c50797a114cd519dd28ba2ac6764":[3,0,0,1,21,13],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a80392ad926f2c048de1cc20b47b4dff2":[3,0,0,1,21,16],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a8c0f7d3f046929631a3ff42fa3747d6e":[3,0,0,1,21,18],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#a9874fdfe82bd0d75958f9b250750fd56":[3,0,0,1,21,7],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#aa6466285a9f941c080343e69a01a26d0":[3,0,0,1,21,14],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a7081c50797a114cd519dd28ba2ac6764":[3,0,0,1,21,12],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a80392ad926f2c048de1cc20b47b4dff2":[3,0,0,1,21,15],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a8c0f7d3f046929631a3ff42fa3747d6e":[3,0,0,1,21,17],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#a9874fdfe82bd0d75958f9b250750fd56":[3,0,0,1,21,6],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#aa6466285a9f941c080343e69a01a26d0":[3,0,0,1,21,13],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#aae6654470760e4848182efabbcfc0487":[3,0,0,1,21,0],
 "_pro_s_h_a_d_e__peak_search_8hpp.html#ab591c4642541dea6eddb4d19d41b6c42":[3,0,0,1,21,2],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#abbf17a40fb05ae159e7ff915f5e26243":[3,0,0,1,21,10],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#ad294ce59d3158bb67c3afd553d8c8793":[3,0,0,1,21,15],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#adb3b37d77e87360f41cb9529a6e84ce0":[3,0,0,1,21,11],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#ae1faf29aa9f12daea7688c7e24e94ad7":[3,0,0,1,21,8],
-"_pro_s_h_a_d_e__peak_search_8hpp.html#ae8a54558e9c9c28568c441a601811449":[3,0,0,1,21,9],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#abbf17a40fb05ae159e7ff915f5e26243":[3,0,0,1,21,9],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#ad294ce59d3158bb67c3afd553d8c8793":[3,0,0,1,21,14],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#adb3b37d77e87360f41cb9529a6e84ce0":[3,0,0,1,21,10],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#ae1faf29aa9f12daea7688c7e24e94ad7":[3,0,0,1,21,7],
+"_pro_s_h_a_d_e__peak_search_8hpp.html#ae8a54558e9c9c28568c441a601811449":[3,0,0,1,21,8],
 "_pro_s_h_a_d_e__peak_search_8hpp_source.html":[3,0,0,1,21],
 "_pro_s_h_a_d_e__precomputed_values_8cpp.html":[3,0,0,1,22],
 "_pro_s_h_a_d_e__precomputed_values_8cpp_source.html":[3,0,0,1,22],
 "_pro_s_h_a_d_e__precomputed_values_8hpp.html":[3,0,0,1,23],
-"_pro_s_h_a_d_e__precomputed_values_8hpp_source.html":[3,0,0,1,23],
-"_pro_s_h_a_d_e__settings_8hpp.html":[3,0,0,1,24],
-"_pro_s_h_a_d_e__settings_8hpp_source.html":[3,0,0,1,24],
-"_pro_s_h_a_d_e__spheres_8cpp.html":[3,0,0,1,25],
-"_pro_s_h_a_d_e__spheres_8cpp_source.html":[3,0,0,1,25],
-"_pro_s_h_a_d_e__spheres_8hpp.html":[3,0,0,1,26],
-"_pro_s_h_a_d_e__spheres_8hpp.html#a51e14f3a4ce99f8e39497bbce12e28c7":[3,0,0,1,26,4],
-"_pro_s_h_a_d_e__spheres_8hpp.html#a612cf0a1e92ea1e5f0b9bdb820a4b60e":[3,0,0,1,26,3],
-"_pro_s_h_a_d_e__spheres_8hpp.html#a9592e9df40cf87ee1d1c43d6b3508e1c":[3,0,0,1,26,2],
-"_pro_s_h_a_d_e__spheres_8hpp_source.html":[3,0,0,1,26],
-"_pro_s_h_a_d_e__spherical_harmonics_8cpp.html":[3,0,0,1,27],
-"_pro_s_h_a_d_e__spherical_harmonics_8cpp_source.html":[3,0,0,1,27],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html":[3,0,0,1,28],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a0d0b0cf8683acd16bc76285b3897b66f":[3,0,0,1,28,6],
-"_pro_s_h_a_d_e__spherical_harmonics_8hpp.html#a18ff35433a5459c948344bae4bf6284c":[3,0,0,1,28,8]
+"_pro_s_h_a_d_e__precomputed_values_8hpp_source.html":[3,0,0,1,23]
 };
