@@ -18,8 +18,8 @@
 
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.4
-    \date      APR 2022
+    \version   0.7.6.5
+    \date      JUN 2022
 */
 
 //==================================================== ProSHADE
@@ -126,10 +126,10 @@ int main ( int argc, char **argv )
     std::cout << "                                 :      " << rotMat[6] << " ; " << rotMat[7] << " ; " << rotMat[8] << std::endl;
 
     //================================================ Expected output
-//  Optimal rotation Euler angles are:      4.01163 ; 0.698203 ; 5.40945
-//  Optimal rotation matrix is       :      -0.90313 ; 0.118517 ; -0.412686
-//                                   :      0.111992 ; -0.862857 ; -0.492886
-//                                   :      -0.414504 ; -0.491357 ; 0.765999
+//  Optimal rotation Euler angles are:      3.92784 ; 0.706802 ; 5.49658
+//  Optimal rotation matrix is       :      -0.880467 ; 0.120094 ; -0.458645
+//                                   :      0.119463 ; -0.879976 ; -0.459751
+//                                   :      -0.45881 ; -0.459587 ; 0.760443
     
     //================================================ Delete the Patterson maps. They are no longer needed as we will now proceed with phased maps.
     delete staticStr;
@@ -185,8 +185,8 @@ int main ( int argc, char **argv )
     std::cout << "Rot. Centre to optimal overlay translation:  " << optimalTranslation.at(0) << " ; " << optimalTranslation.at(1) << " ; " << optimalTranslation.at(2) << std::endl;
     
     //================================================ Expected output
-//  Rot. Centre to origin translation:           9.14286 ; 17.7778 ; 17.7778
-//  Rot. Centre to optimal overlay translation:  16 ; 24 ; -8
+//  Rot. Centre to origin translation:           13.0909 ; 19.3846 ; 19.3846
+//  Rot. Centre to optimal overlay translation:  12 ; 18 ; -6
     
     //================================================ Write out the output files
     movingStr->writeOutOverlayFiles                   ( settings, optimalEulerRot.at(0), optimalEulerRot.at(1), optimalEulerRot.at(2), &rotationCentre, &optimalTranslation );
