@@ -15,8 +15,8 @@
  
     \author    Michal Tykac
     \author    Garib N. Murshudov
-    \version   0.7.6.4
-    \date      APR 2022
+    \version   0.7.6.5
+    \date      JUN 2022
  */
 
 //==================================================== Include PyBind11 header
@@ -47,6 +47,7 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def_readwrite                                ( "requestedResolution",                  &ProSHADE_settings::requestedResolution                 )
         .def_readwrite                                ( "changeMapResolution",                  &ProSHADE_settings::changeMapResolution                 )
         .def_readwrite                                ( "changeMapResolutionTriLinear",         &ProSHADE_settings::changeMapResolutionTriLinear        )
+        .def_readwrite                                ( "resolutionOversampling",               &ProSHADE_settings::resolutionOversampling              )
     
         .def_readwrite                                ( "pdbBFactorNewVal",                     &ProSHADE_settings::pdbBFactorNewVal                    )
     
@@ -111,6 +112,8 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def_readwrite                                ( "recommendedSymmetryFold",              &ProSHADE_settings::recommendedSymmetryFold             )
         .def_readwrite                                ( "requestedSymmetryType",                &ProSHADE_settings::requestedSymmetryType               )
         .def_readwrite                                ( "requestedSymmetryFold",                &ProSHADE_settings::requestedSymmetryFold               )
+        .def_readwrite                                ( "maxSymmetryFold",                      &ProSHADE_settings::maxSymmetryFold                     )
+        .def_readwrite                                ( "supportedSymmetryFold",                &ProSHADE_settings::supportedSymmetryFold               )
         .def_readwrite                                ( "useBiCubicInterpolationOnPeaks",       &ProSHADE_settings::useBiCubicInterpolationOnPeaks      )
         .def_readwrite                                ( "maxSymmetryFold",                      &ProSHADE_settings::maxSymmetryFold                     )
         .def_readwrite                                ( "fscThreshold",                         &ProSHADE_settings::fscThreshold                        )
@@ -147,6 +150,7 @@ void add_settingsClass ( pybind11::module& pyProSHADE )
         .def                                          ( "setOutputFilename",                    &ProSHADE_settings::setOutputFilename,                      "Sets the requested output file name in the appropriate variable.",                                                         pybind11::arg ( "oFileName"     ) )
         .def                                          ( "setMapResolutionChange",               &ProSHADE_settings::setMapResolutionChange,                 "Sets the requested map resolution change decision in the appropriate variable.",                                           pybind11::arg ( "mrChange"      ) )
         .def                                          ( "setMapResolutionChangeTriLinear",      &ProSHADE_settings::setMapResolutionChangeTriLinear,        "Sets the requested map resolution change decision using tri-linear interpolation in the appropriate variable.",            pybind11::arg ( "mrChange"      ) )
+        .def                                          ( "setMapResolutionOverSampling",         &ProSHADE_settings::setMapResolutionOverSampling,           "Sets the requested map resolution over-sampling.",                                                                         pybind11::arg ( "overS"         ) )
         .def                                          ( "setMapCentering",                      &ProSHADE_settings::setMapCentering,                        "Sets the requested map centering decision value in the appropriate variable.",                                             pybind11::arg ( "com"           ) )
         .def                                          ( "setExtraSpace",                        &ProSHADE_settings::setExtraSpace,                          "Sets the requested map extra space value in the appropriate variable.",                                                    pybind11::arg ( "exSpace"       ) )
         .def                                          ( "setCoordExtraSpace",                   &ProSHADE_settings::setCoordExtraSpace,                     "Sets the requested co-ordinates extra space value in the appropriate variable.",                                                    pybind11::arg ( "exSpace"       ) )
